==> open-xchange-core_7.4.0.orig.tar.bz2: open-xchange-core-7.4.0/com.openexchange.tokenlogin/src/com/openexchange/tokenlogin/DefaultTokenLoginSecret.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2020 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.tokenlogin;

import java.util.Collections;
import java.util.Map;
import com.openexchange.java.StringAllocator;

/**
 * {@link DefaultTokenLoginSecret} - The default implementation for {@link TokenLoginSecret}.
 *
 * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
 */
public class DefaultTokenLoginSecret implements TokenLoginSecret {

    private String secret;
    private Map<String, Object> parameters;

    /**
     * Initializes a new {@link DefaultTokenLoginSecret}.
     */
    public DefaultTokenLoginSecret() {
        super();
    }

    @Override
    public String getSecret() {
        return secret;
    }

    /**
     * Sets the secret
     *
     * @param secret The secret to set
     * @return This instance with new argument applied
     */
    public DefaultTokenLoginSecret setSecret(final String secret) {
        this.secret = secret;
        return this;
    }

    @Override
    public Map<String, Object> getParameters() {
        return null == parameters ? Collections.<String, Object> emptyMap() : parameters;
    }

    /**
     * Sets the parameters
     *
     * @param parameters The parameters to set
     * @return This instance with new argument applied
     */
    public DefaultTokenLoginSecret setParameters(final Map<String, Object> parameters) {
        this.parameters = Collections.unmodifiableMap(parameters);
        return this;
    }

    @Override
    public String toString() {
        final StringAllocator builder = new StringAllocator(64);
        builder.append("DefaultTokenLoginSecret [");
        if (secret != null) {
            builder.append("secret=").append(secret).append(", ");
        }
        if (parameters != null) {
            builder.append("parameters=").append(parameters);
        }
        builder.append("]");
        return builder.toString();
    }

}

==> open-xchange-core_7.6.1.orig.tar.bz2: open-xchange-core-7.6.1/com.openexchange.tokenlogin/src/com/openexchange/tokenlogin/DefaultTokenLoginSecret.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2020 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.tokenlogin;

import java.util.Collections;
import java.util.Map;

/**
 * {@link DefaultTokenLoginSecret} - The default implementation for {@link TokenLoginSecret}.
 *
 * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
 */
public class DefaultTokenLoginSecret implements TokenLoginSecret {

    private String secret;
    private Map<String, Object> parameters;

    /**
     * Initializes a new {@link DefaultTokenLoginSecret}.
     */
    public DefaultTokenLoginSecret() {
        super();
    }

    @Override
    public String getSecret() {
        return secret;
    }

    /**
     * Sets the secret
     *
     * @param secret The secret to set
     * @return This instance with new argument applied
     */
    public DefaultTokenLoginSecret setSecret(final String secret) {
        this.secret = secret;
        return this;
    }

    @Override
    public Map<String, Object> getParameters() {
        return null == parameters ? Collections.<String, Object> emptyMap() : parameters;
    }

    /**
     * Sets the parameters
     *
     * @param parameters The parameters to set
     * @return This instance with new argument applied
     */
    public DefaultTokenLoginSecret setParameters(final Map<String, Object> parameters) {
        this.parameters = Collections.unmodifiableMap(parameters);
        return this;
    }

    @Override
    public String toString() {
        final StringBuilder builder = new StringBuilder(64);
        builder.append("DefaultTokenLoginSecret [");
        if (secret != null) {
            builder.append("secret=").append(secret).append(", ");
        }
        if (parameters != null) {
            builder.append("parameters=").append(parameters);
        }
        builder.append("]");
        return builder.toString();
    }

}
